"""Model Utilities for Workbench models"""

import logging
import pandas as pd

# Set up the log
log = logging.getLogger("workbench")


def model_instance_info() -> pd.DataFrame:
    """Get the instance information for the Model"""
    data = [
        {
            "Instance Name": "ml.t2.medium",
            "vCPUs": 2,
            "Memory": 4,
            "Price per Hour": 0.06,
            "Category": "General",
            "Architecture": "x86",
        },
        {
            "Instance Name": "ml.m7i.large",
            "vCPUs": 2,
            "Memory": 8,
            "Price per Hour": 0.12,
            "Category": "General",
            "Architecture": "x86",
        },
        {
            "Instance Name": "ml.c7i.large",
            "vCPUs": 2,
            "Memory": 4,
            "Price per Hour": 0.11,
            "Category": "Compute",
            "Architecture": "x86",
        },
        {
            "Instance Name": "ml.c7i.xlarge",
            "vCPUs": 4,
            "Memory": 8,
            "Price per Hour": 0.21,
            "Category": "Compute",
            "Architecture": "x86",
        },
    ]
    """Right Now we do not support ARM64 instances, but we could add them in the future
    {
        "Instance Name": "ml.c7g.large",
        "vCPUs": 2,
        "Memory": 4,
        "Price per Hour": 0.09,
        "Category": "Compute",
        "Architecture": "ARM64",
    },
    {
        "Instance Name": "ml.c7g.xlarge",
        "vCPUs": 4,
        "Memory": 8,
        "Price per Hour": 0.17,
        "Category": "Compute",
        "Architecture": "ARM64",
    },
    """
    return pd.DataFrame(data)


def supported_instance_types() -> list:
    """Get the supported instance types for the Model/Model"""

    # Just return the "Instance Name" column
    return list(model_instance_info()["Instance Name"])


if __name__ == "__main__":
    """Exercise the Model Utilities"""

    # Get the instance information
    print(model_instance_info())

    # Get the supported instance types
    print(supported_instance_types())
